/**
 * Created by littwin on 14.03.15.
 */
window.frontEnd = true;
window.lang = "<?php _('LANGUAGE') ?>";

var app = angular.module('frontapp', ['ngAnimate', 'ui.router', 'ui.bootstrap', 'ngSanitize', 'FrontRouter', 'RSBase', 'RSUser'])
    .config(['$stateProvider', '$urlRouterProvider', '$compileProvider', function ($stateProvider, $urlRouterProvider, $compileProvider) {
      //$compileProvider.debugInfoEnabled(false); // For faster processing disable debug
      $urlRouterProvider.otherwise("/print");
      //localStorageServiceProvider.setPrefix("RServer");
    }])
    // The front controller handles all global functions
    .controller('FrontController', ['$scope', '$rootScope', 'RSCom', 'User', 'RSOverview', 'RSPrinter', 'GSettings', 'KeyboardInteger', 'FEQuestion', '$http', '$uibModal',
      function ($scope, $rootScope, RSCom, User, RSOverview, RSPrinter, GSettings, KeyboardInteger, FEQuestion, $http, $uibModal) {
        $rootScope.user = User;
        $rootScope.RSPrinter = RSPrinter;
        $scope.overview = RSOverview;
        window.rs = $rootScope;
        $rootScope.activeSlug = ""; // no printer preselected
        $scope.supportedLanguages = {};
        $http.get("/languages.json").then(function (data) {
          $scope.supportedLanguages = data.data;
        });
        // Extend settings with our frontend settings if not presend
        GSettings.promise.then(function () {
          var defaultFrontSetting = {
            listType: 0,
            language: "en",
            "showEmergency": true,
            listSort: 0,
            listPerPage: 25,
            showFullscreen: false,
            goWebInterface: false
          };
          if (!$rootScope.serverSettings.frontSetting) {
            $rootScope.serverSettings.frontSetting = defaultFrontSetting;
            GSettings.serverSettingsChanged();
          } else {
            var changed = false;
            angular.forEach(defaultFrontSetting, function (val, key) {
              if (typeof($rootScope.serverSettings.frontSetting[key]) === "undefined") {
                $rootScope.serverSettings.frontSetting[key] = val;
                changed = true;
              }
            });
            if (changed)
              GSettings.serverSettingsChanged();
          }
        });

        $scope.selectLanguage = function (lang) {
          l = document.URL;
          lp = l.indexOf("lang=");
          if (lp < 0) {
            lp = l.indexOf("#");
            lp2 = l.indexOf("?");
            if (lp2 < 0) {
              if (lp < 0) lp = l.length;
              l = l.substr(0, lp) + "?lang=" + lang + l.substr(lp);
            } else {

              l = l.substr(0, lp) + "&lang=" + lang + l.substr(lp);
            }
          } else {
            l = l.substr(0, lp + 5) + lang + l.substr(lp + 7);
          }
          window.location = l;
        };

        // Changes printing variable to allow some controls to get disabled while printing
        $rootScope.$watchGroup(['active.state.isJobActive', 'active.status.paused'], function () {
          if (!$rootScope.active || !$rootScope.active.state) return;
          $scope.printing = $rootScope.active.state.isJobActive && !$rootScope.active.status.paused;
        });

        // The active printer is the first printer in list or the first printer being online
        // That way plugging in a printer automatically activates that printer.
        $rootScope.$on("printerListUpdated", function (list) {
          var newSlug = $rootScope.activeSlug;
          angular.forEach($rootScope.printerList, function (p) {
            if (newSlug == '' || (p.online && $rootScope.printer[newSlug].status.online == 0))
              newSlug = p.slug;
          });
          if (newSlug != $rootScope.activeSlug)
            RSOverview.selectPrinter(newSlug);
        });
        // Change extruder temperature
        $scope.changeExtruderTemp = function (index, e) {
          KeyboardInteger(" <?php _('Extruder') ?> " + (index + 1), "rs rs-extruder", 0, $rootScope.activeConfig.extruders[index].maxTemp, "°C", $rootScope.active.state.extruder[index].tempSet).then(function (s) {
            RSPrinter.setExtruderTemperature(index, s);
          });
        };

        $scope.disableExtruder = function (index) {
          if ($rootScope.active.state.isJobActive) {
            FEQuestion("<?php _('Security Question') ?>", "<?php _('Print in progress. Really disable extruder?') ?>", "<?php _('Yes') ?>", "<?php _('No') ?>", true).then(function () {
              RSPrinter.setExtruderTemperature(index, 0);
            });
          } else {
            RSPrinter.setExtruderTemperature(index, 0);
          }
        };

        $scope.disableBed = function (index) {
          if ($rootScope.active.state.isJobActive) {
            FEQuestion("<?php _('Security Question') ?>", "<?php _('Print in progress. Really disable heated bed?') ?>", "<?php _('Yes') ?>", "<?php _('No') ?>", true).then(function () {
              RSPrinter.setBedTemperature(0);
            });
          } else {
            RSPrinter.setBedTemperature(0);
          }
        };

        $scope.changeSpeed = function () {
          KeyboardInteger(" <?php _('Speed') ?>", "rs rs-speed", 25, 300, "%", $rootScope.active.state.speedMultiply).then(function (s) {
            RSPrinter.speedChange(s);
          });
        };

        $scope.changeFlow = function () {
          KeyboardInteger(" <?php _('Flow') ?>", "rs rs-flow", 25, 300, "%", $rootScope.active.state.flowMultiply).then(function (s) {
            RSPrinter.flowChange(s);
          });
        };

        $scope.changeFanSpeed = function () {
          KeyboardInteger(" <?php _('Fan') ?>", "rs rs-fan", 0, 100, "%", $rootScope.active.state.fans[0].percent).then(function (s) {
            RSPrinter.setFanPercent(s,0);
          });
        };

        $scope.changeBedTemp = function () {
          KeyboardInteger(" <?php _('Bed') ?>", "rs rs-heated-bed", 0, $rootScope.activeConfig.heatedBeds[0].maxTemp, "°C", $rootScope.active.state.heatedBeds[0].tempSet).then(function (s) {
            RSPrinter.setBedTemperature(s,0);
          });
        };

        $scope.emergencyStop = function () {
          FEQuestion("<?php _('Security Question') ?>", "<?php _('Execute Emergency Stop?') ?>", "<?php _('Yes') ?>", "<?php _('No') ?>", true).then(function () {
            RSCom.send("send", {cmd: "M112"});
          });
        };

        $scope.fullsizeImage = function (imgUrl) {
          var templ = '<div class="modal-body pointer" ng-click="$dismiss()"><img src="' + imgUrl + '" style="max-width:100%"></div>';
          $uibModal.open({template: templ, windowTemplateUrl: "views/dialogs/fullsizeImage.html"});
        };

        $scope.runExternalCommand = function (id) {
          var cmd = $rootScope.externalCommands[id];
          if (cmd.confirm.length > 0) {
            FEQuestion("<?php _('Security Question') ?>", cmd.confirm, "<?php _('Yes') ?>", "<?php _('No') ?>", true).then(function () {
              RSCom.send("runExternalCommand", {id: id});
            });
          } else
            RSCom.send("runExternalCommand", {id: id});
        };
        var cachedQr = {};
        $scope.qr = function (ip, port, margin, modsize) {
          if (!margin) margin = 0;
          if (!modsize) modsize = 4;
          var link = $rootScope.httpType + "://" + ip + ":" + port;
          var res = cachedQr[link];
          if (!res) {
            res = QRCode.generatePNG(link, {modulesize: modsize, margin: margin});
            cachedQr[link] = res;
          }
          return res;
        };
      }])
    .factory('RSPrinterConfig', function () {
      // Fake for fullfilling dependiecies
      return {};
    })
  ;

